package com.huiju.estateagents.sample.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.common.StringUtils;
import com.huiju.estateagents.sample.entity.TaContact;
import com.huiju.estateagents.sample.entity.TaH5Sample;
import com.huiju.estateagents.sample.entity.TaSampleContact;
import com.huiju.estateagents.sample.service.ITaContactService;
import com.huiju.estateagents.sample.service.ITaH5SampleService;
import com.huiju.estateagents.sample.service.ITaSampleContactService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

import java.time.LocalDateTime;
import java.util.List;

/**
 * <p>
    * 样例表  前端控制器
    * </p>
 *
 * @author fxf
 * @since 2020-03-18
 */
@RestController
@RequestMapping("/api")
public class TaH5SampleController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaH5SampleController.class);

    @Autowired
    public ITaH5SampleService iTaH5SampleService;

    @Autowired
    public ITaSampleContactService iTaSampleContactService;

    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/ListH5SampleByCondition",method= RequestMethod.GET)
    public ResponseBean ListH5SampleByCondition(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                       @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                       String sampleName){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<TaH5Sample> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaH5Sample> queryWrapper = new QueryWrapper<>();
            queryWrapper.like("sample_name",sampleName);
            queryWrapper.orderByDesc("order_no","create_date");

            IPage<TaH5Sample> result = iTaH5SampleService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taH5SampleList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param taH5Sample 实体对象
     * @return
     */
    @RequestMapping(value="/taH5Sample",method= RequestMethod.POST)
    public ResponseBean taH5SampleAdd(@RequestBody TaH5Sample taH5Sample){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaH5SampleService.save(taH5Sample)){
                responseBean.addSuccess(taH5Sample);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taH5SampleAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/taH5Sample/{id}", method= RequestMethod.DELETE)
    public ResponseBean taH5SampleDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTaH5SampleService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taH5SampleDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taH5Sample 实体对象
     * @return
     */
    @RequestMapping(value="/taH5Sample/{id}",method= RequestMethod.PUT)
    public ResponseBean taH5SampleUpdate(@PathVariable Integer id,
                                        @RequestBody TaH5Sample taH5Sample){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaH5SampleService.updateById(taH5Sample)){
                responseBean.addSuccess(taH5Sample);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taH5SampleUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taH5Sample/{id}",method= RequestMethod.GET)
    public ResponseBean taH5SampleGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaH5SampleService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taH5SampleDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/channel/h5Sample/list",method= RequestMethod.GET)
    public ResponseBean geth5SampleList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                        @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                        String sampleName){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
            IPage<TaH5Sample> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaH5Sample> queryWrapper = new QueryWrapper<>();
            queryWrapper.like(!StringUtils.isEmpty(sampleName),"sample_name",sampleName);
            queryWrapper.orderByDesc("order_no","create_date");

            IPage<TaH5Sample> result = iTaH5SampleService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taH5SampleList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param taH5Sample 实体对象
     * @return
     */
    @RequestMapping(value="/channel/h5Sample/add",method= RequestMethod.POST)
    public ResponseBean AddTaH5Sample(@RequestBody TaH5Sample taH5Sample){
        ResponseBean responseBean = new ResponseBean();
        try {
            List<String> tags = taH5Sample.getTags();
            taH5Sample.setTag(String.join(",",tags));
            taH5Sample.setCreateDate(LocalDateTime.now());
            if (iTaH5SampleService.save(taH5Sample)){
                List<TaContact> taContactList = taH5Sample.getTaContactList();
                taContactList.forEach(e -> {
                    TaSampleContact taSampleContact = new TaSampleContact();
                    taSampleContact.setContactId(e.getContactId());
                    taSampleContact.setSampleId(taH5Sample.getSampleId());
                    iTaSampleContactService.save(taSampleContact);
                });
                responseBean.addSuccess(taH5Sample);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taH5SampleAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
